Class: Railbow::Status::Ghosts::Row

Inherits:
Object
  • Object
show all
Defined in:
lib/railbow/status/ghosts.rb

Overview

A ghost normalized for rendering, whether it came from mighost's orphan classification or from a live snapshot recovery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(filename: nil, branch_name: nil, source: nil, superseded_by: nil, deleted_in_sha: nil, author_name: nil, author_email: nil, content: nil) ⇒ Row

Returns a new instance of Row.



18
19
20
21
22
23
24
25
26
27
28
# File 'lib/railbow/status/ghosts.rb', line 18

def initialize(filename: nil, branch_name: nil, source: nil, superseded_by: nil,
  deleted_in_sha: nil, author_name: nil, author_email: nil, content: nil)
  @filename = filename
  @branch_name = branch_name
  @source = source
  @superseded_by = superseded_by
  @deleted_in_sha = deleted_in_sha
  @author_name = author_name
  @author_email = author_email
  @content = content
end

Instance Attribute Details

#author_emailObject (readonly)

Returns the value of attribute author_email.



15
16
17
# File 'lib/railbow/status/ghosts.rb', line 15

def author_email
  @author_email
end

#author_nameObject (readonly)

Returns the value of attribute author_name.



15
16
17
# File 'lib/railbow/status/ghosts.rb', line 15

def author_name
  @author_name
end

#branch_nameObject (readonly)

Returns the value of attribute branch_name.



15
16
17
# File 'lib/railbow/status/ghosts.rb', line 15

def branch_name
  @branch_name
end

#contentObject (readonly)

Returns the value of attribute content.



15
16
17
# File 'lib/railbow/status/ghosts.rb', line 15

def content
  @content
end

#deleted_in_shaObject (readonly)

Returns the value of attribute deleted_in_sha.



15
16
17
# File 'lib/railbow/status/ghosts.rb', line 15

def deleted_in_sha
  @deleted_in_sha
end

#filenameObject (readonly)

Returns the value of attribute filename.



15
16
17
# File 'lib/railbow/status/ghosts.rb', line 15

def filename
  @filename
end

#sourceObject (readonly)

Returns the value of attribute source.



15
16
17
# File 'lib/railbow/status/ghosts.rb', line 15

def source
  @source
end

#superseded_byObject (readonly)

Returns the value of attribute superseded_by.



15
16
17
# File 'lib/railbow/status/ghosts.rb', line 15

def superseded_by
  @superseded_by
end