Class: Railbow::Status::Ghosts::Row
- Inherits:
-
Object
- Object
- Railbow::Status::Ghosts::Row
- Defined in:
- lib/railbow/status/ghosts.rb
Overview
A ghost normalized for rendering, whether it came from mighost's orphan classification or from a live snapshot recovery.
Instance Attribute Summary collapse
-
#author_email ⇒ Object
readonly
Returns the value of attribute author_email.
-
#author_name ⇒ Object
readonly
Returns the value of attribute author_name.
-
#branch_name ⇒ Object
readonly
Returns the value of attribute branch_name.
-
#content ⇒ Object
readonly
Returns the value of attribute content.
-
#deleted_in_sha ⇒ Object
readonly
Returns the value of attribute deleted_in_sha.
-
#filename ⇒ Object
readonly
Returns the value of attribute filename.
-
#source ⇒ Object
readonly
Returns the value of attribute source.
-
#superseded_by ⇒ Object
readonly
Returns the value of attribute superseded_by.
Instance Method Summary collapse
-
#initialize(filename: nil, branch_name: nil, source: nil, superseded_by: nil, deleted_in_sha: nil, author_name: nil, author_email: nil, content: nil) ⇒ Row
constructor
A new instance of Row.
Constructor Details
#initialize(filename: nil, branch_name: nil, source: nil, superseded_by: nil, deleted_in_sha: nil, author_name: nil, author_email: nil, content: nil) ⇒ Row
Returns a new instance of Row.
18 19 20 21 22 23 24 25 26 27 28 |
# File 'lib/railbow/status/ghosts.rb', line 18 def initialize(filename: nil, branch_name: nil, source: nil, superseded_by: nil, deleted_in_sha: nil, author_name: nil, author_email: nil, content: nil) @filename = filename @branch_name = branch_name @source = source @superseded_by = superseded_by @deleted_in_sha = deleted_in_sha @author_name = @author_email = @content = content end |
Instance Attribute Details
#author_email ⇒ Object (readonly)
Returns the value of attribute author_email.
15 16 17 |
# File 'lib/railbow/status/ghosts.rb', line 15 def @author_email end |
#author_name ⇒ Object (readonly)
Returns the value of attribute author_name.
15 16 17 |
# File 'lib/railbow/status/ghosts.rb', line 15 def @author_name end |
#branch_name ⇒ Object (readonly)
Returns the value of attribute branch_name.
15 16 17 |
# File 'lib/railbow/status/ghosts.rb', line 15 def branch_name @branch_name end |
#content ⇒ Object (readonly)
Returns the value of attribute content.
15 16 17 |
# File 'lib/railbow/status/ghosts.rb', line 15 def content @content end |
#deleted_in_sha ⇒ Object (readonly)
Returns the value of attribute deleted_in_sha.
15 16 17 |
# File 'lib/railbow/status/ghosts.rb', line 15 def deleted_in_sha @deleted_in_sha end |
#filename ⇒ Object (readonly)
Returns the value of attribute filename.
15 16 17 |
# File 'lib/railbow/status/ghosts.rb', line 15 def filename @filename end |
#source ⇒ Object (readonly)
Returns the value of attribute source.
15 16 17 |
# File 'lib/railbow/status/ghosts.rb', line 15 def source @source end |
#superseded_by ⇒ Object (readonly)
Returns the value of attribute superseded_by.
15 16 17 |
# File 'lib/railbow/status/ghosts.rb', line 15 def superseded_by @superseded_by end |